// Earth animation
const earthAnimation = () => {
  const earth = document.querySelector('.earth-animation');
  let scrollPosition = 0;
  
  const updateEarth = () => {
    scrollPosition = window.scrollY;
    const maxScroll = document.body.scrollHeight - window.innerHeight;
    const progress = Math.min(scrollPosition / maxScroll, 1);
    
    // Change text based on scroll progress
    if (progress < 0.33) {
      earth.innerHTML = '<p>🌎 Neelato - One small switch for you, one big future for all</p>';
    } else if (progress < 0.66) {
      earth.innerHTML = '<p>🌍 Neelato - One small switch for you, one big future for all</p>';
    } else {
      earth.innerHTML = '<p>🌏 Neelato - One small switch for you, one big future for all</p>';
    }
  };
  
  window.addEventListener('scroll', updateEarth);
  updateEarth();
};

// Testimonial slider
const testimonialSlider = () => {
  const testimonials = document.querySelectorAll('.testimonial');
  let currentIndex = 0;
  
  const showTestimonial = (index) => {
    testimonials.forEach((testimonial, i) => {
      testimonial.style.display = i === index ? 'block' : 'none';
    });
  };
  
  const nextTestimonial = () => {
    currentIndex = (currentIndex + 1) % testimonials.length;
    showTestimonial(currentIndex);
  };
  
  // Show first testimonial initially
  showTestimonial(0);
  
  // Change testimonial every 5 seconds
  setInterval(nextTestimonial, 5000);
};

// Counter animation
const animateCounters = () => {
  const counters = document.querySelectorAll('.counter-item h3');
  const speed = 200;
  
  counters.forEach(counter => {
    const target = +counter.innerText.replace(/,/g, '');
    const count = +counter.dataset.count || 0;
    const increment = target / speed;
    
    if (count < target) {
      counter.innerText = Math.ceil(count + increment).toLocaleString();
      counter.dataset.count = count + increment;
      setTimeout(animateCounters, 1);
    } else {
      counter.innerText = target.toLocaleString();
    }
  });
};

// Initialize all functions when DOM is loaded
document.addEventListener('DOMContentLoaded', () => {
  earthAnimation();
  testimonialSlider();
  
  // Only animate counters when they come into view
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        animateCounters();
        observer.unobserve(entry.target);
      }
    });
  }, { threshold: 0.5 });
  
  document.querySelectorAll('.impact-counter').forEach(section => {
    observer.observe(section);
  });
});

// Smooth scrolling for navigation links
document.querySelectorAll('a[href^="#"]').forEach(anchor => {
  anchor.addEventListener('click', function(e) {
    e.preventDefault();
    
    const targetId = this.getAttribute('href');
    if (targetId === '#') return;
    
    const targetElement = document.querySelector(targetId);
    if (targetElement) {
      targetElement.scrollIntoView({
        behavior: 'smooth'
      });
    }
  });
});